summaryrefslogtreecommitdiffstats
path: root/kexi/main/keximainwindowimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/main/keximainwindowimpl.cpp')
-rw-r--r--kexi/main/keximainwindowimpl.cpp116
1 files changed, 58 insertions, 58 deletions
diff --git a/kexi/main/keximainwindowimpl.cpp b/kexi/main/keximainwindowimpl.cpp
index 5594d577..3071dd38 100644
--- a/kexi/main/keximainwindowimpl.cpp
+++ b/kexi/main/keximainwindowimpl.cpp
@@ -111,7 +111,7 @@
# define KexiVDebug if (0) kdDebug()
#endif
//first fix the tqgeometry
//#define KEXI_NO_CTXT_HELP 1
#ifndef KEXI_NO_CTXT_HELP
@@ -127,7 +127,7 @@
//! width changes will be removed in KMDI
//#define PROPEDITOR_VISIBILITY_CHANGES
//temporary fix to manage tqlayout
#include "ksplitter.h"
#define KDOCKWIDGET_P 1
@@ -245,8 +245,8 @@ KexiMainWindowImpl::KexiMainWindowImpl()
int scnum = TQApplication::desktop()->screenNumber(parentWidget());
TQRect desk = TQApplication::desktop()->screenGeometry(scnum);
d->config->setGroup("MainWindow");
- TQSize s ( d->config->readNumEntry( TQString::tqfromLatin1("Width %1").tqarg(desk.width()), 700 ),
- d->config->readNumEntry( TQString::tqfromLatin1("Height %1").tqarg(desk.height()), 480 ) );
+ TQSize s ( d->config->readNumEntry( TQString::fromLatin1("Width %1").arg(desk.width()), 700 ),
+ d->config->readNumEntry( TQString::fromLatin1("Height %1").arg(desk.height()), 480 ) );
resize (kMin (s.width(), desk.width()), kMin(s.height(), desk.height()));
}
@@ -360,7 +360,7 @@ KexiMainWindowImpl::KexiMainWindowImpl()
TQToolButton *closeButton = new TQToolButton( tabWidget() );
closeButton->setAutoRaise( true );
closeButton->setPixmap( TQPixmap( kde2_closebutton ) );
- closeButton->setPaletteBackgroundColor(closeButton->tqpalette().active().background());
+ closeButton->setPaletteBackgroundColor(closeButton->palette().active().background());
// closeButton->setIconSet(SmallIconSet("tab_remove"));
tabWidget()->setCornerWidget( closeButton, TQt::TopRight );
closeButton->hide(); // hide until it's needed to avoid problems in "user mode"
@@ -465,7 +465,7 @@ void KexiMainWindowImpl::switchToIDEAlMode(bool showMessage)
else {
KMessageBox::information(this,
i18n("User interface mode will be switched to IDEAl at next %1 application startup.")
- .tqarg(KEXI_APP_NAME));
+ .arg(KEXI_APP_NAME));
//delayed
d->mdiModeToSwitchAfterRestart = KMdi::IDEAlMode;
}
@@ -492,7 +492,7 @@ void KexiMainWindowImpl::switchToChildframeMode(bool showMessage)
else {
KMessageBox::information(this,
i18n("User interface mode will be switched to Childframe at next %1 application startup.")
- .tqarg(KEXI_APP_NAME));
+ .arg(KEXI_APP_NAME));
//delayed
d->mdiModeToSwitchAfterRestart = KMdi::ChildframeMode;
}
@@ -1281,7 +1281,7 @@ static TQString internalReason(KexiDB::Object *obj)
const TQString &s = obj->errorMsg();
if (s.isEmpty())
return s;
- return TQString("<br>(%1) ").tqarg(i18n("reason:")+" <i>"+s+"</i>");
+ return TQString("<br>(%1) ").arg(i18n("reason:")+" <i>"+s+"</i>");
}
tristate KexiMainWindowImpl::openProject(const KexiProjectData& projectData)
@@ -1319,7 +1319,7 @@ tristate KexiMainWindowImpl::openProject(const KexiProjectData& projectData)
if (incompatibleWithKexi) {
if (KMessageBox::Yes == KMessageBox::questionYesNo(this,
i18n("<qt>Database project %1 does not appear to have been created using Kexi.<br><br>"
- "Do you want to import it as a new Kexi project?</qt>").tqarg(projectData.infoString()),
+ "Do you want to import it as a new Kexi project?</qt>").arg(projectData.infoString()),
0, KGuiItem(i18n("Import Database", "&Import..."), "database_import"),
KStdGuiItem::quit()))
{
@@ -1447,9 +1447,9 @@ void KexiMainWindowImpl::slotAutoOpenObjectsLater()
not_found_msg += (TQString("\"") + info["name"] + "\" - ");
if (info["action"]=="new")
not_found_msg += i18n("cannot create object - unknown object type \"%1\"")
- .tqarg(info["type"]);
+ .arg(info["type"]);
else
- not_found_msg += i18n("unknown object type \"%1\"").tqarg(info["type"]);
+ not_found_msg += i18n("unknown object type \"%1\"").arg(info["type"]);
not_found_msg += internalReason(&Kexi::partManager())+"<br></li>";
continue;
}
@@ -1457,7 +1457,7 @@ void KexiMainWindowImpl::slotAutoOpenObjectsLater()
if (info["action"]=="new") {
if (!newObject( i, openingCancelled) && !openingCancelled) {
not_found_msg += "<li>";
- not_found_msg += (i18n("cannot create object of type \"%1\"").tqarg(info["type"])+
+ not_found_msg += (i18n("cannot create object of type \"%1\"").arg(info["type"])+
internalReason(d->prj)+"<br></li>");
}
else
@@ -1551,7 +1551,7 @@ void KexiMainWindowImpl::slotAutoOpenObjectsLater()
if (!not_found_msg.isEmpty())
showErrorMessage(i18n("You have requested selected objects to be automatically opened "
"or processed on startup. Several objects cannot be opened or processed."),
- TQString("<ul>%1</ul>").tqarg(not_found_msg) );
+ TQString("<ul>%1</ul>").arg(not_found_msg) );
d->updatePropEditorVisibility(d->curDialog ? d->curDialog->currentViewMode() : 0);
#if defined(KDOCKWIDGET_P)
@@ -1788,7 +1788,7 @@ void KexiMainWindowImpl::slotLastActions()
}
#endif
#ifdef TQ_WS_WIN
- showMaximized();//js: workaround for not yet completed tqlayout settings storage on win32
+ showMaximized();//js: workaround for not yet completed layout settings storage on win32
#endif
}
@@ -1836,7 +1836,7 @@ void KexiMainWindowImpl::initPropertyEditor()
//1 dw->setMinimumWidth(200);
- // ds->setSeparatorPos(d->propEditor->tqsizeHint().width(), true);
+ // ds->setSeparatorPos(d->propEditor->sizeHint().width(), true);
//heh, this is for IDEAl only, I suppose?
//js if (m_rightContainer) {
@@ -1864,7 +1864,7 @@ void KexiMainWindowImpl::slotPartLoaded(KexiPart::Part* p)
}
//! internal
-void KexiMainWindowImpl::slotCaptionForCurrentMDIChild(bool tqchildrenMaximized)
+void KexiMainWindowImpl::slotCaptionForCurrentMDIChild(bool childrenMaximized)
{
//js todo: allow to set custom "static" app caption
@@ -1877,18 +1877,18 @@ void KexiMainWindowImpl::slotCaptionForCurrentMDIChild(bool tqchildrenMaximized)
//current dialog isn't attached! - find top level child
if (m_pMdi->topChild()) {
view = m_pMdi->topChild()->m_pClient;
- tqchildrenMaximized = view->mdiParent()->state()==KMdiChildFrm::Maximized;
+ childrenMaximized = view->mdiParent()->state()==KMdiChildFrm::Maximized;
}
else
view = 0;
}
- if (tqchildrenMaximized && view) {
+ if (childrenMaximized && view) {
setCaption( d->curDialog->caption()
- + (d->appCaptionPrefix.isEmpty() ? TQString() : (TQString::tqfromLatin1(" - ") + d->appCaptionPrefix)) );
+ + (d->appCaptionPrefix.isEmpty() ? TQString() : (TQString::fromLatin1(" - ") + d->appCaptionPrefix)) );
}
else {
- setCaption( (d->appCaptionPrefix.isEmpty() ? TQString() : (d->appCaptionPrefix + TQString::tqfromLatin1(" - ")))
+ setCaption( (d->appCaptionPrefix.isEmpty() ? TQString() : (d->appCaptionPrefix + TQString::fromLatin1(" - ")))
+ d->origAppCaption );
}
}
@@ -2093,8 +2093,8 @@ KexiMainWindowImpl::restoreSettings()
}*/
config->setGroup("MainWindow");
- TQSize s ( config->readNumEntry( TQString::tqfromLatin1("Width %1").tqarg(desk.width()), 700 ),
- config->readNumEntry( TQString::tqfromLatin1("Height %1").tqarg(desk.height()), 480 ) );
+ TQSize s ( config->readNumEntry( TQString::fromLatin1("Width %1").arg(desk.width()), 700 ),
+ config->readNumEntry( TQString::fromLatin1("Height %1").arg(desk.height()), 480 ) );
resize (kMin (s.width(), desk.width()), kMin(s.height(), desk.height()));
}
#endif
@@ -3006,10 +3006,10 @@ bool KexiMainWindowImpl::switchToViewMode(int viewMode)
}
if (!d->curDialog->supportsViewMode( viewMode )) {
showErrorMessage(i18n("Selected view is not supported for \"%1\" object.")
- .tqarg(d->curDialog->partItem()->name()),
+ .arg(d->curDialog->partItem()->name()),
i18n("Selected view (%1) is not supported by this object type (%2).")
- .tqarg(Kexi::nameForViewMode(viewMode))
- .tqarg(d->curDialog->part()->instanceCaption()) );
+ .arg(Kexi::nameForViewMode(viewMode))
+ .arg(d->curDialog->part()->instanceCaption()) );
d->toggleLastCheckedMode();
return false;
}
@@ -3019,7 +3019,7 @@ bool KexiMainWindowImpl::switchToViewMode(int viewMode)
tristate res = d->curDialog->switchToViewMode( viewMode );
if (!res) {
updateCustomPropertyPanelTabs(0, Kexi::NoViewMode); //revert
- showErrorMessage(i18n("Switching to other view failed (%1).").tqarg(Kexi::nameForViewMode(viewMode)),
+ showErrorMessage(i18n("Switching to other view failed (%1).").arg(Kexi::nameForViewMode(viewMode)),
d->curDialog);
d->toggleLastCheckedMode();
return false;
@@ -3118,7 +3118,7 @@ tristate KexiMainWindowImpl::getNewObjectInfo(
if (allowOverwriting) {
int res = KMessageBox::warningYesNoCancel(this,
"<p>"+part->i18nMessage("Object \"%1\" already exists.", 0)
- .tqarg(d->nameDialog->widget()->nameText())
+ .arg(d->nameDialog->widget()->nameText())
+"</p><p>"+i18n("Do you want to replace it?")+"</p>", 0,
KGuiItem(i18n("&Replace"), "button_yes"),
KGuiItem(i18n("&Choose Other Name...")),
@@ -3135,11 +3135,11 @@ tristate KexiMainWindowImpl::getNewObjectInfo(
else {
KMessageBox::information(this,
"<p>"+part->i18nMessage("Object \"%1\" already exists.", 0)
- .tqarg(d->nameDialog->widget()->nameText())
+ .arg(d->nameDialog->widget()->nameText())
+"</p><p>"+i18n("Please choose other name.")+"</p>");
// " For example: Table \"my_table\" already exists" ,
// "%1 \"%2\" already exists.\nPlease choose other name.")
-// .tqarg(dlg->part()->instanceName()).tqarg(d->nameDialog->widget()->nameText()));
+// .arg(dlg->part()->instanceName()).arg(d->nameDialog->widget()->nameText()));
continue;
}
}
@@ -3160,7 +3160,7 @@ tristate KexiMainWindowImpl::saveObject( KexiDialogBase *dlg, const TQString& me
//data was saved in the past -just save again
res = dlg->storeData(dontAsk);
if (!res)
- showErrorMessage(i18n("Saving \"%1\" object failed.").tqarg(dlg->partItem()->name()),
+ showErrorMessage(i18n("Saving \"%1\" object failed.").arg(dlg->partItem()->name()),
d->curDialog);
return res;
}
@@ -3177,7 +3177,7 @@ tristate KexiMainWindowImpl::saveObject( KexiDialogBase *dlg, const TQString& me
if (~res)
return cancelled;
if (!res) {
- showErrorMessage(i18n("Saving new \"%1\" object failed.").tqarg(dlg->partItem()->name()),
+ showErrorMessage(i18n("Saving new \"%1\" object failed.").arg(dlg->partItem()->name()),
d->curDialog);
return false;
}
@@ -3224,11 +3224,11 @@ tristate KexiMainWindowImpl::closeDialog(KexiDialogBase *dlg, bool layoutTaskBar
saveChanges.setToolTip(i18n("Save changes"));
saveChanges.setWhatsThis(
i18n( "Pressing this button will save all recent changes made in \"%1\" object." )
- .tqarg(dlg->partItem()->name()) );
+ .arg(dlg->partItem()->name()) );
KGuiItem discardChanges( KStdGuiItem::discard() );
discardChanges.setWhatsThis(
i18n( "Pressing this button will discard all recent changes made in \"%1\" object." )
- .tqarg(dlg->partItem()->name()) );
+ .arg(dlg->partItem()->name()) );
//dialog's data is dirty:
//--adidional message, e.g. table designer will return
@@ -3243,7 +3243,7 @@ tristate KexiMainWindowImpl::closeDialog(KexiDialogBase *dlg, bool layoutTaskBar
const int questionRes = KMessageBox::warningYesNoCancel( this,
"<p>"+dlg->part()->i18nMessage("Design of object \"%1\" has been modified.", dlg)
- .tqarg(dlg->partItem()->name())+"</p><p>"+i18n("Do you want to save changes?")+"</p>"
+ .arg(dlg->partItem()->name())+"</p><p>"+i18n("Do you want to save changes?")+"</p>"
+ additionalMessage /*may be empty*/,
TQString(),
saveChanges,
@@ -3380,9 +3380,9 @@ void KexiMainWindowImpl::attachWindow(KMdiChildView *pWnd, bool /*bShow*/, bool
KMdiMainFrm::attachWindow(pWnd,true,bAutomaticResize);
//for dialogs in normal state: decrease dialog's height if it exceeds area contents
if (pWnd->mdiParent()->state() == KMdiChildFrm::Normal
- && pWnd->tqgeometry().bottom() > pWnd->mdiParent()->mdiAreaContentsRect().bottom())
+ && pWnd->geometry().bottom() > pWnd->mdiParent()->mdiAreaContentsRect().bottom())
{
- TQRect r = pWnd->tqgeometry();
+ TQRect r = pWnd->geometry();
r.setBottom( pWnd->mdiParent()->mdiAreaContentsRect().bottom() - 5 );
pWnd->setGeometry( r );
}
@@ -3444,7 +3444,7 @@ bool KexiMainWindowImpl::eventFilter( TQObject *obj, TQEvent * e )
/* Fixes for popup menus behaviour:
For hiding/showing: focus previously (d->focus_before_popup)
focused window, if known, otherwise focus currently focused one.
- And: just tqinvalidate actions.
+ And: just invalidate actions.
*/
if (e->type()==TQEvent::Hide || e->type()==TQEvent::Show) {
KexiVDebug << e->type() << endl;
@@ -3479,10 +3479,10 @@ bool KexiMainWindowImpl::eventFilter( TQObject *obj, TQEvent * e )
KexiVDebug << (focus_w ? focus_w->name() : "" ) << endl;
KexiVDebug << "eventFilter: " <<e->type() << " " <<obj->name() <<endl;
#ifdef KEXI_STATUSBAR_DEBUG
- TQWidget *focus_widget = focus_w ? focus_w->tqfocusWidget() : 0;
- d->statusBar->settqStatus(TQString("FOCUS VIEW: %1 %2, FOCUS WIDGET: %3 %4")
- .tqarg(focus_w ? focus_w->className() : "").tqarg(focus_w ? focus_w->name() : "")
- .tqarg(focus_widget ? focus_widget->className() : "").tqarg(focus_widget ? focus_widget->name() : "")
+ TQWidget *focus_widget = focus_w ? focus_w->focusWidget() : 0;
+ d->statusBar->setStatus(TQString("FOCUS VIEW: %1 %2, FOCUS WIDGET: %3 %4")
+ .arg(focus_w ? focus_w->className() : "").arg(focus_w ? focus_w->name() : "")
+ .arg(focus_widget ? focus_widget->className() : "").arg(focus_widget ? focus_widget->name() : "")
);
#endif
}
@@ -3492,10 +3492,10 @@ bool KexiMainWindowImpl::eventFilter( TQObject *obj, TQEvent * e )
KexiVDebug << (focus_w ? focus_w->name() : "" ) << endl;
KexiVDebug << "eventFilter: " <<e->type() << " " <<obj->name() <<endl;
#ifdef KEXI_STATUSBAR_DEBUG
- TQWidget *focus_widget = focus_w ? focus_w->tqfocusWidget() : 0;
- d->statusBar->settqStatus(TQString("FOCUS VIEW: %1 %2, FOCUS WIDGET: %3 %4")
- .tqarg(focus_w ? focus_w->className() : "").tqarg(focus_w ? focus_w->name() : "")
- .tqarg(focus_widget ? focus_widget->className() : "").tqarg(focus_widget ? focus_widget->name() : "")
+ TQWidget *focus_widget = focus_w ? focus_w->focusWidget() : 0;
+ d->statusBar->setStatus(TQString("FOCUS VIEW: %1 %2, FOCUS WIDGET: %3 %4")
+ .arg(focus_w ? focus_w->className() : "").arg(focus_w ? focus_w->name() : "")
+ .arg(focus_widget ? focus_widget->className() : "").arg(focus_widget ? focus_widget->name() : "")
);
#endif
}
@@ -3512,7 +3512,7 @@ bool KexiMainWindowImpl::eventFilter( TQObject *obj, TQEvent * e )
// invalidateSharedActions();
}
else {
-/* TQObject* o = tqfocusWidget();
+/* TQObject* o = focusWidget();
while (o && !o->inherits("KexiDialogBase") && !o->inherits("KexiDockBase"))
o = o->parent();*/
//js invalidateSharedActions(focus_w);
@@ -3534,7 +3534,7 @@ bool KexiMainWindowImpl::eventFilter( TQObject *obj, TQEvent * e )
return true;
}
//remember currently focued window tqinvalidate act.
if (e->type()==TQEvent::FocusOut) {
if (TQT_TQFOCUSEVENT(e)->reason()==TQFocusEvent::Popup) {
if (KexiUtils::hasParent(TQT_TQOBJECT(d->curDialog), TQT_TQOBJECT(focus_w))) {
@@ -3605,7 +3605,7 @@ KexiMainWindowImpl::openObject(KexiPart::Item* item, int viewMode, bool &opening
if (!openingAllowed(item, viewMode)) {
if (errorMessage)
*errorMessage = i18n("opening is not allowed in \"data view/design view/text view\" mode",
- "opening is not allowed in \"%1\" mode").tqarg(Kexi::nameForViewMode(viewMode));
+ "opening is not allowed in \"%1\" mode").arg(Kexi::nameForViewMode(viewMode));
openingCancelled = true;
return 0;
}
@@ -3790,7 +3790,7 @@ tristate KexiMainWindowImpl::removeObject( KexiPart::Item *item, bool dontAsk )
"<p>"+i18n("Do you want to permanently delete:\n"
"%1\n"
"If you click \"Delete\", you will not be able to undo the deletion.")
- .tqarg( "</p><p>"+part->instanceCaption()+" \""+ item->name() + "\"?</p>" ),
+ .arg( "</p><p>"+part->instanceCaption()+" \""+ item->name() + "\"?</p>" ),
0, KGuiItem(i18n("Delete"), "editdelete"), KStdGuiItem::no()))
return cancelled;
}
@@ -3865,7 +3865,7 @@ void KexiMainWindowImpl::renameObject( KexiPart::Item *item, const TQString& _ne
const bool res = d->prj->renameObject(this, *item, newName);
enableMessages(true);
if (!res) {
- showErrorMessage( d->prj, i18n("Renaming object \"%1\" failed.").tqarg(newName) );
+ showErrorMessage( d->prj, i18n("Renaming object \"%1\" failed.").arg(newName) );
success = false;
return;
}
@@ -3980,7 +3980,7 @@ void KexiMainWindowImpl::importantInfo(bool /*onStartup*/)
if (onStartup && !d->showImportantInfoOnStartup)
return;
- TQString key = TQString("showImportantInfo %1").tqarg(KEXI_VERSION_STRING);
+ TQString key = TQString("showImportantInfo %1").arg(KEXI_VERSION_STRING);
d->config->setGroup("Startup");
bool show = d->config->readBoolEntry(key,true);
@@ -4005,7 +4005,7 @@ void KexiMainWindowImpl::importantInfo(bool /*onStartup*/)
ts.setCodec( KGlobal::locale()->codecForEncoding() );
TQTextBrowser *tb = KexiUtils::findFirstChild<KTextBrowser>(&tipDialog,"KTextBrowser");
if (tb) {
- tb->setText( TQString("<qt>%1</qt>").tqarg(ts.read()) );
+ tb->setText( TQString("<qt>%1</qt>").arg(ts.read()) );
}
f.close();
}
@@ -4062,7 +4062,7 @@ KexiMainWindowImpl::initUserMode(KexiProjectData *projectData)
#if 0 //todo reenable; autoopen objects are handled elsewhere
KexiDB::TableSchema *sch = d->prj->dbConnection()->tableSchema("kexi__final");
TQString err_msg = i18n("Could not start project \"%1\" in Final Mode.")
- .tqarg(static_cast<KexiDB::SchemaData*>(projectData)->name());
+ .arg(static_cast<KexiDB::SchemaData*>(projectData)->name());
if(!sch)
{
hide();
@@ -4184,7 +4184,7 @@ void KexiMainWindowImpl::slotToolsCompactDatabase()
if (!drv || !(drv->features() & KexiDB::Driver::CompactingDatabaseSupported)) {
KMessageBox::information(this, "<qt>"+
i18n("Compacting database file <nobr>\"%1\"</nobr> is not supported.")
- .tqarg(TQDir::convertSeparators(cdata.fileName())));
+ .arg(TQDir::convertSeparators(cdata.fileName())));
return;
}
data = new KexiProjectData( cdata, cdata.fileName() );
@@ -4409,7 +4409,7 @@ tristate KexiMainWindowImpl::printActionForItem(KexiPart::Item* item, PrintActio
if (dlg) {
// accept row changes
- TQWidget *prevFocusWidget = tqfocusWidget();
+ TQWidget *prevFocusWidget = focusWidget();
dlg->setFocus();
d->action_data_save_row->activate();
if (prevFocusWidget)
@@ -4423,11 +4423,11 @@ tristate KexiMainWindowImpl::printActionForItem(KexiPart::Item* item, PrintActio
saveChanges.setToolTip(i18n("Save changes"));
saveChanges.setWhatsThis(
i18n( "Pressing this button will save all recent changes made in \"%1\" object." )
- .tqarg(item->name()) );
+ .arg(item->name()) );
KGuiItem doNotSave( KStdGuiItem::no() );
doNotSave.setWhatsThis(
i18n( "Pressing this button will ignore all unsaved changes made in \"%1\" object." )
- .tqarg(dlg->partItem()->name()) );
+ .arg(dlg->partItem()->name()) );
TQString question;
if (action == PrintItem)
@@ -4441,7 +4441,7 @@ tristate KexiMainWindowImpl::printActionForItem(KexiPart::Item* item, PrintActio
const int questionRes = KMessageBox::warningYesNoCancel( this,
"<p>"+dlg->part()->i18nMessage("Design of object \"%1\" has been modified.", dlg)
- .tqarg(item->name()) + "</p><p>" + question + "</p>",
+ .arg(item->name()) + "</p><p>" + question + "</p>",
TQString(),
saveChanges,
doNotSave);
@@ -111,7 +111,7 @@
# define KexiVDebug if (0) kdDebug()
#endif
-//first fix the tqgeometry
+//first fix the geometry
//#define KEXI_NO_CTXT_HELP 1
#ifndef KEXI_NO_CTXT_HELP
@@ -127,7 +127,7 @@
//! width changes will be removed in KMDI
//#define PROPEDITOR_VISIBILITY_CHANGES
-//temporary fix to manage tqlayout
+//temporary fix to manage layout
#include "ksplitter.h"
#define KDOCKWIDGET_P 1
@@ -3534,7 +3534,7 @@ bool KexiMainWindowImpl::eventFilter( TQObject *obj, TQEvent * e )
return true;
}
- //remember currently focued window tqinvalidate act.
+ //remember currently focued window invalidate act.
if (e->type()==TQEvent::FocusOut) {
if (TQT_TQFOCUSEVENT(e)->reason()==TQFocusEvent::Popup) {